@@ -2,6 +2,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 from amaascore.market_data.eod_price import EODPrice
 from amaascore.market_data.fx_rate import FXRate
+from amaascore.market_data.curve import Curve
 
 
 def json_to_eod_price(json_eod_price):
@@ -13,3 +14,6 @@ def json_to_fx_rate(json_fx_rate):
     fx_rate = FXRate(**json_fx_rate)
     return fx_rate
 
+def json_to_curve(json_curve):
+    curve = Curve(**json_curve)
+    return curve
\ No newline at end of file
