@@ -6,7 +6,8 @@ import json
 from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
-from amaascore.transactions.utils import json_to_transaction, json_to_position, json_to_mtm_result, json_to_transaction_pnl, json_to_position_pnl
+from amaascore.transactions.utils import json_to_transaction, json_to_position, \
+    json_to_mtm_result, json_to_transaction_pnl, json_to_position_pnl
 
 
 class TransactionsInterface(Interface):
@@ -340,7 +341,7 @@ class TransactionsInterface(Interface):
             response.raise_for_status()        
 
     def position_search(self, asset_manager_id, book_ids=None, account_ids=None,
-                        accounting_types=['Transaction Date'], asset_ids=None,
+                        accounting_types=None, asset_ids=None,
                         position_date=None, include_cash=False, 
                         page_no=None, page_size=None):
         self.logger.info('Search Positions - Asset Manager: %s', asset_manager_id)
